import { dataSource } from "../data-source";
import { permission } from "../entity/permission";
import InternalException from "../exceptions/internalException";

export default abstract class PermissionService {
  /**
   * @description get permission by user
   * @param user number
   * @returns {Promise<Array<permission>>}
   */
  static async getByUser(userId: number): Promise<Array<permission>> {
    return await dataSource
      .getRepository(permission)
      .createQueryBuilder("permission")
      .where("permission.userId = :userId", { userId: userId })
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("permission not found by user");
      });
  }
}
